==> ingdao-0.0.1.tar.gz: lib/ingdao.dart <==
library ingdao;

import 'dataflow/control/dfquery.dart';
import 'dataflow/repository/dfbaserepository.dart';
import 'dataflow/control/dfresponse.dart';

class DfFactory {
  DfFactory._();
  static final instance = DfFactory._();
  Map<String, DfBaseRepository> repositories = Map<String, DfBaseRepository>();
  DfBaseRepository currentRepository;
  String _currentRepositoryName;

  registerRepository(String name, DfBaseRepository repository) {
    repositories[name] = repository;
  }

  activateRepository(String name) async {
    _currentRepositoryName = name;
    currentRepository = repositories[name];
    //adapters.forEach((k,v) => v.stop()); 
    await currentRepository.startInit();
  }

  String getActivatedRepositoryName() {
    return _currentRepositoryName;
  }

  Future<DfResponse> fetch(DfQuery query, {DfBaseRepository repository}) async {
    DfBaseRepository repo = repository != null ? repository : currentRepository;
    return await repo.fetch(query);
  }

  Future<List<DfResponse>> save(List<DfQuery> queries, {DfBaseRepository repository}) async {
    DfBaseRepository repo = repository != null ? repository : currentRepository;
    return await repo.save(queries);
  }

  Future<List<DfResponse>> delete(List<DfQuery> queries, {DfBaseRepository repository}) async {
    DfBaseRepository repo = repository != null ? repository : currentRepository;
    return await repo.delete(queries);
  }

  Future<DfResponse> fetchCount(DfQuery query, {DfBaseRepository repository}) async {
    DfBaseRepository repo = repository != null ? repository : currentRepository;
    return await repo.fetchCount(query);
  }
}

// /// A Calculator.
// class Calculator {
//   /// Returns [value] plus 1.
//   int addOne(int value) => value + 1;
// }

==> ingdao-0.0.19.tar.gz: lib/ingdao.dart <==
library ingdao;

import 'dataflow/control/dfquery.dart';
import 'dataflow/repository/dfbaserepository.dart';
import 'dataflow/control/dfresponse.dart';

class DfFactory {
  // DfFactory._();
  // static final instance = DfFactory._();
  Map<String, DfBaseRepository> repositories = Map<String, DfBaseRepository>();
  DfBaseRepository currentRepository;
  String _currentRepositoryName;

  registerRepository(String name, DfBaseRepository repository) {
    repositories[name] = repository;
  }

  activateRepository(String name) async {
    _currentRepositoryName = name;
    currentRepository = repositories[name];
    //adapters.forEach((k,v) => v.stop()); 
    await currentRepository.startInit();
  }

  String getActivatedRepositoryName() {
    return _currentRepositoryName;
  }

  Future<DfResponse> fetch(DfQuery query, {DfBaseRepository repository}) async {
    DfBaseRepository repo = repository != null ? repository : currentRepository;
    return await repo.fetch(query);
  }

  Future<List<DfResponse>> save(List<DfQuery> queries, {DfBaseRepository repository}) async {
    DfBaseRepository repo = repository != null ? repository : currentRepository;
    return await repo.save(queries);
  }

  Future<List<DfResponse>> delete(List<DfQuery> queries, {DfBaseRepository repository}) async {
    DfBaseRepository repo = repository != null ? repository : currentRepository;
    return await repo.delete(queries);
  }

  Future<DfResponse> fetchCount(DfQuery query, {DfBaseRepository repository}) async {
    DfBaseRepository repo = repository != null ? repository : currentRepository;
    return await repo.fetchCount(query);
  }
}

// /// A Calculator.
// class Calculator {
//   /// Returns [value] plus 1.
//   int addOne(int value) => value + 1;
// }
